"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, NotRequired, TypedDict


class GetHrisLocationsPositiveResponseAddressTypedDict(TypedDict):
    r"""The work location’s address"""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class GetHrisLocationsPositiveResponseAddress(BaseModel):
    r"""The work location’s address"""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "city",
            "country",
            "raw",
            "state",
            "street_1",
            "street_2",
            "zip_code",
        ]
        nullable_fields = [
            "city",
            "country",
            "raw",
            "state",
            "street_1",
            "street_2",
            "zip_code",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisLocationsPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The work location’s name"""
    type: Nullable[str]
    r"""The work location’s type. A freeform string."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    address: NotRequired[Nullable[GetHrisLocationsPositiveResponseAddressTypedDict]]
    r"""The work location’s address"""


class GetHrisLocationsPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The work location’s name"""

    type: Nullable[str]
    r"""The work location’s type. A freeform string."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    address: OptionalNullable[GetHrisLocationsPositiveResponseAddress] = UNSET
    r"""The work location’s address"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["address"]
        nullable_fields = ["remote_id", "name", "address", "type", "remote_deleted_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisLocationsPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisLocationsPositiveResponseResultTypedDict]


class GetHrisLocationsPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisLocationsPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisLocationsPositiveResponseTypedDict(TypedDict):
    data: GetHrisLocationsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisLocationsPositiveResponse(BaseModel):
    data: GetHrisLocationsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getintegrationsintegrationidcustomfieldspositiveresponse import (
    GetIntegrationsIntegrationIDCustomFieldsPositiveResponse,
    GetIntegrationsIntegrationIDCustomFieldsPositiveResponseTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Awaitable, Callable, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class GetIntegrationsIntegrationIDCustomFieldsRequestTypedDict(TypedDict):
    integration_id: str
    r"""GET /integrations/:integration_id/custom-fields Parameter"""
    cursor: NotRequired[str]
    r"""An optional cursor string used for pagination. This can be retrieved from the `next` property of the previous page response."""
    page_size: NotRequired[int]
    r"""The number of results to return per page. Maximum is 250."""


class GetIntegrationsIntegrationIDCustomFieldsRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""GET /integrations/:integration_id/custom-fields Parameter"""

    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""An optional cursor string used for pagination. This can be retrieved from the `next` property of the previous page response."""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""The number of results to return per page. Maximum is 250."""


class GetIntegrationsIntegrationIDCustomFieldsResponseTypedDict(TypedDict):
    result: GetIntegrationsIntegrationIDCustomFieldsPositiveResponseTypedDict


class GetIntegrationsIntegrationIDCustomFieldsResponse(BaseModel):
    next: Union[
        Callable[[], Optional[GetIntegrationsIntegrationIDCustomFieldsResponse]],
        Callable[
            [], Awaitable[Optional[GetIntegrationsIntegrationIDCustomFieldsResponse]]
        ],
    ]

    result: GetIntegrationsIntegrationIDCustomFieldsPositiveResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getatsapplicationspositiveresponse import (
    GetAtsApplicationsPositiveResponse,
    GetAtsApplicationsPositiveResponseTypedDict,
)
from datetime import datetime
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, HeaderMetadata, QueryParamMetadata
import pydantic
from typing import Awaitable, Callable, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class GetAtsApplicationsGlobalsTypedDict(TypedDict):
    integration_id: NotRequired[str]
    r"""ID of the integration you want to interact with."""


class GetAtsApplicationsGlobals(BaseModel):
    integration_id: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Integration-Id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""ID of the integration you want to interact with."""


class GetAtsApplicationsRequestTypedDict(TypedDict):
    cursor: NotRequired[str]
    r"""An optional cursor string used for pagination. This can be retrieved from the `next` property of the previous page response."""
    page_size: NotRequired[int]
    r"""The number of results to return per page. Maximum is 250."""
    updated_after: NotRequired[datetime]
    r"""Filter the entries based on the modification date in format `YYYY-MM-DDTHH:mm:ss.sssZ`. Returns records where either the record itself **OR** its nested data has been updated since this timestamp, even if the record's own `changed_at` field remains unchanged.

    If you want to track entry deletion, also set the `include_deleted=true` query parameter, because otherwise, deleted entries will be hidden.

    For more details, see [Understanding changed_at vs updated_after Behavior](https://docs.kombo.dev/ats/getting-started/fetching-data#understanding-changed_at-vs-updated_after-behavior).
    """
    include_deleted: NotRequired[bool]
    r"""By default, deleted entries are not returned. Use the `include_deleted` query param to include deleted entries too."""
    ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of IDs such as `222k7eCGyUdgt2JWZDNnkDs3,B5DVmypWENfU6eMe6gYDyJG3`."""
    remote_ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of remote IDs."""
    outcomes: NotRequired[List[str]]
    r"""Filter by a comma-separated list of `PENDING`, `HIRED`, `DECLINED`
    * `PENDING`: The application is still being processed.
    * `HIRED`: The candidate was hired.
    * `DECLINED`: The candidate was declined.


    Leave this blank to get results matching all values.
    """
    job_ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of job IDs. We will only return applications that are related to _any_ of the jobs."""
    job_remote_ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of job remote IDs. We will only return applications that are related to _any_ of the jobs."""
    current_stage_ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of application stage IDs. We will only return applications that are currently in _any_ of the stages."""
    remote_created_after: NotRequired[datetime]
    r"""Filter applications by the day they were created in the remote system. This allows you to get applications that were created on or after a certain day."""


class GetAtsApplicationsRequest(BaseModel):
    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""An optional cursor string used for pagination. This can be retrieved from the `next` property of the previous page response."""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""The number of results to return per page. Maximum is 250."""

    updated_after: Annotated[
        Optional[datetime],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter the entries based on the modification date in format `YYYY-MM-DDTHH:mm:ss.sssZ`. Returns records where either the record itself **OR** its nested data has been updated since this timestamp, even if the record's own `changed_at` field remains unchanged.

    If you want to track entry deletion, also set the `include_deleted=true` query parameter, because otherwise, deleted entries will be hidden.

    For more details, see [Understanding changed_at vs updated_after Behavior](https://docs.kombo.dev/ats/getting-started/fetching-data#understanding-changed_at-vs-updated_after-behavior).
    """

    include_deleted: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = False
    r"""By default, deleted entries are not returned. Use the `include_deleted` query param to include deleted entries too."""

    ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of IDs such as `222k7eCGyUdgt2JWZDNnkDs3,B5DVmypWENfU6eMe6gYDyJG3`."""

    remote_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of remote IDs."""

    outcomes: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of `PENDING`, `HIRED`, `DECLINED`
    * `PENDING`: The application is still being processed.
    * `HIRED`: The candidate was hired.
    * `DECLINED`: The candidate was declined.


    Leave this blank to get results matching all values.
    """

    job_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of job IDs. We will only return applications that are related to _any_ of the jobs."""

    job_remote_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of job remote IDs. We will only return applications that are related to _any_ of the jobs."""

    current_stage_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of application stage IDs. We will only return applications that are currently in _any_ of the stages."""

    remote_created_after: Annotated[
        Optional[datetime],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter applications by the day they were created in the remote system. This allows you to get applications that were created on or after a certain day."""


class GetAtsApplicationsResponseTypedDict(TypedDict):
    result: GetAtsApplicationsPositiveResponseTypedDict


class GetAtsApplicationsResponse(BaseModel):
    next: Union[
        Callable[[], Optional[GetAtsApplicationsResponse]],
        Callable[[], Awaitable[Optional[GetAtsApplicationsResponse]]],
    ]

    result: GetAtsApplicationsPositiveResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostAtsCandidatesCandidateIDResultLinksRequestBodyAttributeTypedDict(TypedDict):
    key: str
    r"""The name of the attribute"""
    value: str
    r"""The value of the attribute"""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyAttribute(BaseModel):
    key: str
    r"""The name of the attribute"""

    value: str
    r"""The value of the attribute"""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyDetailsTypedDict(TypedDict):
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """

    custom_field_name_prefix: str
    r"""That will be added to the attribute labels if they are used for custom fields. If you specify `Acme:` as the prefix, the custom field will be named `Acme: Score`. Putting in the name of your company/product is a good idea."""
    attributes: List[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyAttributeTypedDict
    ]


class PostAtsCandidatesCandidateIDResultLinksRequestBodyDetails(BaseModel):
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """

    custom_field_name_prefix: str
    r"""That will be added to the attribute labels if they are used for custom fields. If you specify `Acme:` as the prefix, the custom field will be named `Acme: Score`. Putting in the name of your company/product is a good idea."""

    attributes: List[PostAtsCandidatesCandidateIDResultLinksRequestBodyAttribute]


class PostAtsCandidatesCandidateIDResultLinksRequestBodyIcimsTypedDict(TypedDict):
    r"""Fields specific to iCIMS."""

    assessment_package_id: NotRequired[str]
    r"""The package ID of the assessment that the result link will be added to."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyIcims(BaseModel):
    r"""Fields specific to iCIMS."""

    assessment_package_id: Optional[str] = None
    r"""The package ID of the assessment that the result link will be added to."""


PostAtsCandidatesCandidateIDResultLinksRequestBodyOverrideDocumentCategory = Literal[
    "IRC_CANDIDATE_RESUME",
    "IRC_CANDIDATE_COVERLETTER",
    "MISC",
    "IRC_INTERNAL",
]
r"""Allows you to override the document category for the url. (Default: MISC)"""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyOracleTypedDict(TypedDict):
    r"""Fields specific to Oracle."""

    override_document_category: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyOverrideDocumentCategory
    ]
    r"""Allows you to override the document category for the url. (Default: MISC)"""
    multi_post_to_all_current_applications: NotRequired[bool]
    r"""If true, the result link will be posted to all current applications for the candidate."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyOracle(BaseModel):
    r"""Fields specific to Oracle."""

    override_document_category: Optional[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyOverrideDocumentCategory
    ] = None
    r"""Allows you to override the document category for the url. (Default: MISC)"""

    multi_post_to_all_current_applications: Optional[bool] = None
    r"""If true, the result link will be posted to all current applications for the candidate."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeadersTypedDict(TypedDict):
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    on_behalf_of: NotRequired[Nullable[str]]
    r"""ID of the the user that will show up as having performed the action in Greenhouse. We already pass a value by default, but you can use this to override it."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeaders(BaseModel):
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    on_behalf_of: Annotated[
        OptionalNullable[str], pydantic.Field(alias="On-Behalf-Of")
    ] = UNSET
    r"""ID of the the user that will show up as having performed the action in Greenhouse. We already pass a value by default, but you can use this to override it."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["On-Behalf-Of"]
        nullable_fields = ["On-Behalf-Of"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouseTypedDict(TypedDict):
    r"""Fields specific to Greenhouse."""

    post_headers: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeadersTypedDict
    ]
    r"""Headers we will pass with `POST` requests to Greenhouse."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouse(BaseModel):
    r"""Fields specific to Greenhouse."""

    post_headers: Optional[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeaders
    ] = None
    r"""Headers we will pass with `POST` requests to Greenhouse."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkableTypedDict(TypedDict):
    r"""Workable specific remote fields for ATS actions."""

    on_behalf_of_user_remote_id: NotRequired[str]
    r"""The remote ID of the user that will be displayed in the UI as the one that performed the action."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkable(BaseModel):
    r"""Workable specific remote fields for ATS actions."""

    on_behalf_of_user_remote_id: Optional[str] = None
    r"""The remote ID of the user that will be displayed in the UI as the one that performed the action."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFieldsTypedDict(
    TypedDict
):
    r"""Additional fields that we will pass through to specific ATS systems."""

    icims: NotRequired[PostAtsCandidatesCandidateIDResultLinksRequestBodyIcimsTypedDict]
    r"""Fields specific to iCIMS."""
    oracle: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyOracleTypedDict
    ]
    r"""Fields specific to Oracle."""
    greenhouse: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouseTypedDict
    ]
    r"""Fields specific to Greenhouse."""
    workable: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkableTypedDict
    ]
    r"""Workable specific remote fields for ATS actions."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFields(BaseModel):
    r"""Additional fields that we will pass through to specific ATS systems."""

    icims: Optional[PostAtsCandidatesCandidateIDResultLinksRequestBodyIcims] = None
    r"""Fields specific to iCIMS."""

    oracle: Optional[PostAtsCandidatesCandidateIDResultLinksRequestBodyOracle] = None
    r"""Fields specific to Oracle."""

    greenhouse: Optional[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouse
    ] = None
    r"""Fields specific to Greenhouse."""

    workable: Optional[PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkable] = (
        None
    )
    r"""Workable specific remote fields for ATS actions."""


class PostAtsCandidatesCandidateIDResultLinksRequestBodyTypedDict(TypedDict):
    label: str
    r"""If the system allows us to display a display name for the link, we will use this label."""
    url: str
    r"""URL of the link."""
    details: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyDetailsTypedDict
    ]
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """
    remote_fields: NotRequired[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFieldsTypedDict
    ]
    r"""Additional fields that we will pass through to specific ATS systems."""


class PostAtsCandidatesCandidateIDResultLinksRequestBody(BaseModel):
    label: str
    r"""If the system allows us to display a display name for the link, we will use this label."""

    url: str
    r"""URL of the link."""

    details: Optional[PostAtsCandidatesCandidateIDResultLinksRequestBodyDetails] = None
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """

    remote_fields: Optional[
        PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFields
    ] = None
    r"""Additional fields that we will pass through to specific ATS systems."""
